aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Controller/Persistence
diff options
context:
space:
mode:
authorShadowghost <Ghost_of_Stone@web.de>2026-07-28 12:42:34 +0200
committerShadowghost <Ghost_of_Stone@web.de>2026-07-28 12:43:12 +0200
commiteed664b7d351ae9a22b0722b18d65dcff3fc185d (patch)
treec7a74f40096024617667ab266a65dc5a10d3ec9b /MediaBrowser.Controller/Persistence
parent5b550517b2ca64fee0d060f537901a2bc6604a64 (diff)
Fix played/unplayed filter for empty Series and BoxSets
Diffstat (limited to 'MediaBrowser.Controller/Persistence')
-rw-r--r--MediaBrowser.Controller/Persistence/IItemQueryHelpers.cs8
1 files changed, 4 insertions, 4 deletions
diff --git a/MediaBrowser.Controller/Persistence/IItemQueryHelpers.cs b/MediaBrowser.Controller/Persistence/IItemQueryHelpers.cs
index 2e29cbdbba..e74cc38f7a 100644
--- a/MediaBrowser.Controller/Persistence/IItemQueryHelpers.cs
+++ b/MediaBrowser.Controller/Persistence/IItemQueryHelpers.cs
@@ -79,14 +79,14 @@ public interface IItemQueryHelpers
Guid ancestorId);
/// <summary>
/// Builds an <see cref="IQueryable{Guid}"/> of folder IDs whose descendants are all played
/// for the given user. Composable into outer queries to avoid an extra DB roundtrip.
/// </summary>
/// <param name="context">The database context the resulting query is bound to.</param>
/// <param name="folderIds">A query yielding candidate folder IDs.</param>
/// <param name="user">The user for access filtering and played status.</param>
- /// <returns>An <see cref="IQueryable{Guid}"/> of fully-played folder IDs.</returns>
- IQueryable<Guid> GetFullyPlayedFolderIdsQuery(
+ /// <returns>An <see cref="IQueryable{Guid}"/> of folder IDs with unplayed descendants.</returns>
+ IQueryable<Guid> GetFoldersWithUnplayedItemsQuery(
JellyfinDbContext context,
IQueryable<Guid> folderIds,
User user);
@@ -79,14 +79,14 @@ public interface IItemQueryHelpers
Guid ancestorId);
/// <summary>
- /// Builds an <see cref="IQueryable{Guid}"/> of folder IDs whose descendants are all played
- /// for the given user. Composable into outer queries to avoid an extra DB roundtrip.
+ /// Builds an <see cref="IQueryable{Guid}"/> of folder IDs that have at least one unplayed
+ /// descendant for the given user. Composable into outer queries to avoid an extra DB roundtrip.
/// </summary>
/// <param name="context">The database context the resulting query is bound to.</param>